@@ -192,6 +192,7 @@ Kwave::Plugin *Kwave::PluginManager::createPluginInstance(const QString &name)
     // call the loader function to create an instance
     QVariantList args;
     args << info.m_name;
+    args << info.m_description;
     Kwave::Plugin *plugin = factory->create<Kwave::Plugin>(this, args);
     Q_ASSERT(plugin);
     if (!plugin) {
@@ -319,13 +320,11 @@ void Kwave::PluginManager::sync()
     // this triggers all kinds of garbage collector (objects queued for
     // deletion through obj->deleteLater()
     qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-    qApp->flush();
 
     // wait until all plugins have finished their work...
     while (onePluginRunning()) {
 	Kwave::yield();
 	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-	qApp->flush();
 	usleep(100000);
     }
 }
@@ -641,9 +640,9 @@ void Kwave::PluginManager::searchPluginModules()
 	    continue;
 	}
 
-	if (version != _(PACKAGE_SHORT_VERSION)) {
+	if (version != _(KWAVE_VERSION)) {
 	    qWarning("plugin '%s' has wrong ABI version: '%s' (should be %s)",
-	             DBG(name), DBG(version), PACKAGE_SHORT_VERSION);
+		     DBG(name), DBG(version), KWAVE_VERSION);
 	    continue;
 	}
 
