@@ -352,10 +352,7 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
     unsigned buffer_time = 0; // ring buffer length in us
     snd_pcm_uframes_t period_frames = 0;
     snd_pcm_uframes_t buffer_frames = 0;
-    size_t n = 0;
     snd_pcm_uframes_t start_threshold, stop_threshold;
-    const int start_delay = 0;
-    const int stop_delay = 0;
 
     m_chunk_size = 0;
     if (m_handle) snd_pcm_close(m_handle);
@@ -441,28 +438,22 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
 	return err;
     }
     qDebug("   real rate = %u", rrate);
-    if (static_cast<float>(rate) * 1.05 < rrate ||
-	static_cast<float>(rate) * 0.95 > rrate)
+    if (static_cast<float>(rate) * 1.05f < rrate ||
+	static_cast<float>(rate) * 0.95f > rrate)
     {
 	qWarning("rate is not accurate (requested = %iHz, got = %iHz)",
 	          rate, rrate);
 	qWarning("         please, try the plug plugin (-Dplug:%s)",
 	         snd_pcm_name(m_handle));
     }
-    rate = rrate;
 
-    if ((buffer_time) == 0 && (buffer_frames) == 0) {
-	err = snd_pcm_hw_params_get_buffer_time_max(hw_params, &buffer_time, 0);
-	Q_ASSERT(err >= 0);
-	if (buffer_time > 500000) buffer_time = 500000;
-    }
-
-    if ((period_time == 0) && (period_frames == 0)) {
-	if (buffer_time > 0)
-	    period_time = buffer_time / 4;
-	else
-	    period_frames = buffer_frames / 4;
-    }
+    err = snd_pcm_hw_params_get_buffer_time_max(hw_params, &buffer_time, 0);
+    Q_ASSERT(err >= 0);
+    if (buffer_time > 500000) buffer_time = 500000;
+    if (buffer_time > 0)
+	period_time = buffer_time / 4;
+    else
+	period_frames = buffer_frames / 4;
 
     if (period_time > 0) {
 	err = snd_pcm_hw_params_set_period_time_near(m_handle, hw_params,
@@ -509,20 +500,14 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
     }
 
     err = snd_pcm_sw_params_set_avail_min(m_handle, sw_params, m_chunk_size);
+    Q_ASSERT(err >= 0);
 
     /* round up to closest transfer boundary */
-    start_threshold = static_cast<snd_pcm_uframes_t>(
-	static_cast<double>(rate) * start_delay / 1000000);
-    if (start_delay <= 0) start_threshold += n;
-
-    if (start_threshold < 1) start_threshold = 1;
-    if (start_threshold > n) start_threshold = n;
+    start_threshold = 1;
     err = snd_pcm_sw_params_set_start_threshold(m_handle, sw_params,
                                                 start_threshold);
     Q_ASSERT(err >= 0);
-    stop_threshold = static_cast<snd_pcm_uframes_t>(
-	static_cast<double>(rate) * stop_delay / 1000000);
-    if (stop_delay <= 0) stop_threshold += buffer_size;
+    stop_threshold = buffer_size;
 
     err = snd_pcm_sw_params_set_stop_threshold(m_handle, sw_params,
                                                stop_threshold);
@@ -607,14 +592,14 @@ QString Kwave::PlayBackALSA::open(const QString &device, double rate,
     // resize our buffer and reset it
     Q_ASSERT(m_chunk_size);
     Q_ASSERT(m_bytes_per_sample);
-    unsigned int chunk_bytes = m_chunk_size * m_bytes_per_sample;
+    unsigned int chunk_bytes = Kwave::toUint(m_chunk_size) * m_bytes_per_sample;
     Q_ASSERT(chunk_bytes);
     if (!chunk_bytes) return QString();
     unsigned int n = Kwave::toUint(ceil(
-	static_cast<float>(1 << m_bufbase) /
-	static_cast<float>(chunk_bytes)));
+	static_cast<double>(1 << m_bufbase) /
+	static_cast<double>(chunk_bytes)));
     if (n < 1) n = 1;
-    m_buffer_size = n * m_chunk_size * m_bytes_per_sample;
+    m_buffer_size = n * chunk_bytes;
     m_buffer.resize(m_buffer_size);
     m_buffer_size = m_buffer.size();
 
@@ -659,7 +644,7 @@ int Kwave::PlayBackALSA::flush()
     if (!m_channels || !m_bytes_per_sample) return -EINVAL;
 
     if (m_handle) {
-	unsigned int samples = m_buffer_used / m_bytes_per_sample;
+	snd_pcm_uframes_t samples = m_buffer_used / m_bytes_per_sample;
 	unsigned int buffer_samples = m_buffer_size / m_bytes_per_sample;
 	unsigned int timeout = (m_rate > 0) ?
 	    3 * ((1000 * buffer_samples) /
@@ -670,14 +655,14 @@ int Kwave::PlayBackALSA::flush()
 	if (samples < m_chunk_size) {
 	    snd_pcm_format_set_silence(m_format,
 	        m_buffer.data() + samples * m_bytes_per_sample,
-	        (m_chunk_size - samples) * m_channels);
+	        Kwave::toUint((m_chunk_size - samples) * m_channels));
 	    samples = m_chunk_size;
 	    qDebug("--- added silence ---");
 	}
 
 	while (samples > 0) {
 	    // try to write as much as the device accepts
-	    int r = snd_pcm_writei(m_handle, p, samples);
+	    int r = Kwave::toInt(snd_pcm_writei(m_handle, p, samples));
 	    if ((r == -EAGAIN) || ((r >= 0) && (r < Kwave::toInt(samples))))
 	    {
 		snd_pcm_wait(m_handle, timeout);
